# ludden-logging

![Version](https://img.shields.io/badge/version-0.1.8-navy) ![Python Version](https://img.shields.io/badge/python-3.10%2B-blue) ![Rye](https://img.shields.io/badge/rye-0.9.0-green) ![Rich](https://img.shields.io/badge/rich-10.12.0-brightgreen) ![Loguru](https://img.shields.io/badge/loguru-0.5.3-red)

This is a simple logging library for Python. It is designed to be easy to use and easy to understand. It is not designed to be the most feature-rich logging library, but it should be sufficient for most use cases.
